@@ -80,7 +80,7 @@ class UniqueKeyQueue:
     def clear(self):
         try:
             lock.acquire()
-            self._queue.clear()
+            self._queue.queue.clear()
             self._queue_set.clear()
             self._dict.clear()
         finally:
